@@ -1,9 +1,9 @@
 from enum import Enum
 from typing import Any, Type
 
-from solidlab_perftest_common.agent_command import (
+from solidlab_perftest_common.agent import (
     AgentCommand,
-    AgentStatus,
+    Agent,
     AgentCommandResult,
 )
 
@@ -25,7 +25,7 @@ class SolidLabContentType(Enum):
     def matches_type(self, obj: Any) -> bool:
         if isinstance(obj, AgentCommand):
             return self == SolidLabContentType.AGENT_COMMAND
-        if isinstance(obj, AgentStatus):
+        if isinstance(obj, Agent):
             return self == SolidLabContentType.AGENT_STATUS
         if isinstance(obj, AgentCommandResult):
             return self == SolidLabContentType.AGENT_COMMAND_RESULT
